@@ -1,11 +1,7 @@
-begin
-  require 'rubygems'
-rescue LoadError
-end
 require 'yaml'
 
 class Hiera
-  VERSION = "1.1.0-rc1"
+  VERSION = "1.1.1-rc1"
 
   autoload :Config,         "hiera/config"
   autoload :Util,           "hiera/util"
